# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['rtd']

package_data = \
{'': ['*'],
 'rtd': ['css/*',
         'css/fonts/*',
         'img/*',
         'js/*',
         'locales/de/LC_MESSAGES/*',
         'locales/es/LC_MESSAGES/*',
         'locales/fa/LC_MESSAGES/*',
         'locales/fr/LC_MESSAGES/*',
         'locales/id/LC_MESSAGES/*',
         'locales/it/LC_MESSAGES/*',
         'locales/ja/LC_MESSAGES/*',
         'locales/pt_BR/LC_MESSAGES/*',
         'locales/ru/LC_MESSAGES/*',
         'locales/tr/LC_MESSAGES/*',
         'locales/uk/LC_MESSAGES/*',
         'locales/zh_CN/LC_MESSAGES/*',
         'locales/zh_TW/LC_MESSAGES/*']}

entry_points = \
{'mkdocs.themes': ['rtd = rtd']}

setup_kwargs = {
    'name': 'mkdocs-rtd',
    'version': '0.0.1',
    'description': 'A fork of mkdocs readthedocs theme to make it work with mkapi',
    'long_description': "# mkdocs-rtd\n\nA fork of mkdocs readthedocs theme to make it work better, especially with mkapi.\n\nWhy just use `extra_css` and `extra_javascript`?\n\n- The javascript written in `theme.js` shipped with the original theme has problems expanding the sidebar items and it's not easy to fix it only using `extra_javascript`.\n\n## Installation\n\n```bash\npip install -U mkdocs-rtd\n```\n\n## Usage\n\n```yaml\ntheme:\n  name: rtd\n```\n\nAll options are the same when using the original theme (`readthedocs`). See also:\n<https://www.mkdocs.org/user-guide/choosing-your-theme/#readthedocs>\n",
    'author': 'pwwang',
    'author_email': 'pwwang@pwwang.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
